@@ -6,11 +6,11 @@ DBIx::Schema::Changelog::Action::Default - Handle default values for table colum
 
 =head1 VERSION
 
-Version 0.6.2
+Version 0.7.0
 
 =cut
 
-our $VERSION = '0.6.2';
+our $VERSION = '0.7.0';
 
 use strict;
 use warnings;
@@ -43,9 +43,13 @@ has sequence => (
 =cut
 
 sub add {
-    my ( $self, $params ) = @_;
-    return '' unless $params->{default};
+    my ( $self, $params, $debug ) = @_;
+    print __PACKAGE__, ' (', __LINE__, ') ', $/, Dumper($params)
+      if ($debug);
+    return '' if ( !defined $params->{default} );
     my $defaults = $self->driver()->defaults;
+    print __PACKAGE__, ' (', __LINE__, ') ', $/, Dumper($params)
+      if ($debug);
 
     if ( $params->{default} eq 'inc' ) {
         return $self->sequence()->add($params);
