@@ -6,11 +6,11 @@ DBIx::Schema::Changelog::File::Yaml - module for DBIx::Schema::Changelog::File t
 
 =head1 VERSION
 
-Version 0.6.2
+Version 0.7.0
 
 =cut
 
-our $VERSION = '0.6.2';
+our $VERSION = '0.7.0';
 
 use strict;
 use warnings FATAL => 'all';
@@ -25,12 +25,13 @@ has tpl_main => (
     default => q~
 ---
 templates:
-    tpl_std:
-        - name: id
-          type: integer
-          notnull: 1
-          primarykey: 1
-          default: inc
+    - name: tpl_std
+      columns:
+      - name: id
+        type: integer
+        notnull: 1
+        primarykey: 1
+        default: inc
 
 changelogs: 
   - "01"~,
